@@ -1,7 +1,7 @@
 package Bencher::Scenario::CmdLineParsingModules;
 
-our $DATE = '2016-06-26'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -65,7 +65,7 @@ Bencher::Scenario::CmdLineParsingModules - Benchmark command-line parsing module
 
 =head1 VERSION
 
-This document describes version 0.04 of Bencher::Scenario::CmdLineParsingModules (from Perl distribution Bencher-Scenario-CmdLineParsingModules), released on 2016-06-26.
+This document describes version 0.05 of Bencher::Scenario::CmdLineParsingModules (from Perl distribution Bencher-Scenario-CmdLineParsingModules), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -79,11 +79,15 @@ To run module startup overhead benchmark:
 
 For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.
 
+=head1 DESCRIPTION
+
+Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+
 =head1 BENCHMARKED MODULES
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Complete::Bash> 0.27
+L<Complete::Bash> 0.31
 
 L<Parse::CommandLine> 0.02
 
@@ -125,37 +129,38 @@ Function call template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m CmdLineParsingModules >>):
 
+ #table1#
  +----------------------------------------+--------------+-----------+-----------+------------+---------+---------+
  | participant                            | dataset      | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +----------------------------------------+--------------+-----------+-----------+------------+---------+---------+
- | Parse::CommandLine::parse_command_line | 4args        |     42900 |  23.3     |    1       | 6.4e-09 |      22 |
- | Complete::Bash::parse_cmdline          | 4args        |     49000 |  20.4     |    1.14    | 6.5e-09 |      21 |
- | Complete::Bash::parse_cmdline          | 2args-simple |    117160 |   8.5353  |    2.7292  | 4.7e-11 |      23 |
- | Parse::CommandLine::parse_command_line | 2args-simple |    168000 |   5.95    |    3.92    | 1.5e-09 |      24 |
- | Complete::Bash::parse_cmdline          | cmd-only     |    272000 |   3.67    |    6.34    | 1.4e-09 |      27 |
- | Parse::CommandLine::parse_command_line | cmd-only     |    427079 |   2.34149 |    9.94879 |   0     |      21 |
- | Complete::Bash::parse_cmdline          | empty        |   1500000 |   0.66    |   36       | 8.1e-10 |      21 |
- | Parse::CommandLine::parse_command_line | empty        |   2980000 |   0.335   |   69.5     | 1.6e-10 |      32 |
+ | Parse::CommandLine::parse_command_line | 4args        |     34400 | 29.1      |      1     | 1.2e-08 |      23 |
+ | Complete::Bash::parse_cmdline          | 4args        |     37600 | 26.6      |      1.09  | 1.3e-08 |      20 |
+ | Complete::Bash::parse_cmdline          | 2args-simple |     93300 | 10.7      |      2.71  | 3.1e-09 |      23 |
+ | Parse::CommandLine::parse_command_line | 2args-simple |    140000 |  7.4      |      4     |   1e-08 |      33 |
+ | Complete::Bash::parse_cmdline          | cmd-only     |    200000 |  4.9      |      5.9   | 1.8e-08 |      30 |
+ | Parse::CommandLine::parse_command_line | cmd-only     |    353000 |  2.83     |     10.3   | 7.5e-10 |      25 |
+ | Complete::Bash::parse_cmdline          | empty        |    680000 |  1.5      |     20     | 6.5e-09 |      21 |
+ | Parse::CommandLine::parse_command_line | empty        |   2949840 |  0.339001 |     85.764 |   0     |      20 |
  +----------------------------------------+--------------+-----------+-----------+------------+---------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m CmdLineParsingModules --module-startup >>):
 
- +---------------------+-----------+------------------------+------------+---------+---------+
- | participant         | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
- +---------------------+-----------+------------------------+------------+---------+---------+
- | Parse::CommandLine  |       5.8 |                    3.2 |        1   | 5.4e-05 |      20 |
- | Complete::Bash      |       5.4 |                    2.8 |        1.1 | 2.2e-05 |      21 |
- | perl -e1 (baseline) |       2.6 |                    0   |        2.2 | 1.5e-05 |      20 |
- +---------------------+-----------+------------------------+------------+---------+---------+
+ #table2#
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | participant         | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | Complete::Bash      | 0.83                         | 4.1                | 16             |       9   |                    4.1 |        1   |   2e-05 |      23 |
+ | Parse::CommandLine  | 1.1                          | 4.5                | 16             |       8.8 |                    3.9 |        1   | 3.7e-05 |      20 |
+ | perl -e1 (baseline) | 1                            | 4.3                | 16             |       4.9 |                    0   |        1.8 | 1.3e-05 |      21 |
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
-=head1 DESCRIPTION
 
-Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
 
 =head1 HOMEPAGE
 
@@ -179,7 +184,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
